"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.correlationIdPlugin = void 0;
const uuid_1 = require("uuid");
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
exports.correlationIdPlugin = (0, fastify_plugin_1.default)(
// eslint-disable-next-line @typescript-eslint/require-await
async function correlationIdPlugin(app, opts) {
    const requestHeader = opts.requestHeader || "correlation-id";
    const responseHeader = opts.responseHeader || "Correlation-Id";
    app.decorateRequest("correlationId", "");
    app.addHook("onRequest", (request, reply, done) => {
        const headerValue = request.headers[requestHeader];
        if (!headerValue) {
            // Generate an uuid v4 if header is falsy
            request.correlationId = (0, uuid_1.v4)();
        }
        else if (typeof headerValue === "string") {
            request.correlationId = headerValue;
        }
        else if (Array.isArray(headerValue)) {
            // Take the first value if we received multiple headers
            request.correlationId = headerValue[0];
        }
        // Add the resulting correlationId as response header
        void reply.header(responseHeader, request.correlationId);
        done();
    });
}, {
    name: "correlation-id",
    fastify: "3.x",
});
