"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fastify_1 = __importDefault(require("fastify"));
const correlation_id_1 = require("./correlation_id");
describe("Correlation ID", () => {
    it("adds a generated correlationId uuid to the request object if not provided via header", async () => {
        const app = (0, fastify_1.default)()
            .register(correlation_id_1.correlationIdPlugin)
            .get("/", function (request, reply) {
            expect(this.hasRequestDecorator("correlationId"));
            expect(typeof request.correlationId).toBe("string");
            expect(request.correlationId).not.toBe("");
            void reply.code(200).send();
        });
        await app.ready();
        const { statusCode } = await app.inject({ method: "GET", url: "/" });
        expect(statusCode).toBe(200);
        await app.close();
    });
    it("adds the correlationId from the corresponding header to the request object", async () => {
        const correlationId = "test-correlation-id";
        const app = (0, fastify_1.default)()
            .register(correlation_id_1.correlationIdPlugin)
            .get("/", function (request, reply) {
            expect(this.hasRequestDecorator("correlationId"));
            expect(request.correlationId).toBe(correlationId);
            void reply.code(200).send();
        });
        await app.ready();
        const { statusCode } = await app.inject({
            method: "GET",
            url: "/",
            headers: { "Correlation-Id": correlationId },
        });
        expect(statusCode).toBe(200);
        await app.close();
    });
    it("adds the correlationId response header", async () => {
        const correlationId = "test-correlation-id";
        const app = (0, fastify_1.default)()
            .register(correlation_id_1.correlationIdPlugin)
            .get("/", function (request, reply) {
            void reply.code(200).send();
        });
        await app.ready();
        const response = await app.inject({
            method: "GET",
            url: "/",
            headers: { "Correlation-Id": correlationId },
        });
        expect(response.statusCode).toBe(200);
        expect(response.headers["correlation-id"]).toBe(correlationId);
        await app.close();
    });
});
