import { RequestError, BeforeRequestHook, BeforeRedirectHook, NormalizedOptions } from "got";
import { Logger } from "../logging/logging.types";
import type { PrometheusMeter, Counter, Histogram } from "../metrics";
import type { Response as RequestResponse } from "got/dist/source/core";
export declare class HttpClientInstrumentation {
    private readonly metrics;
    private readonly logger;
    constructor(metrics: HttpClientMetrics, logger: Logger);
    beforeRequest(options: Parameters<BeforeRequestHook>[0]): void;
    receivedResponse(clientResponse: RequestResponse): void;
    beforeRetry(options: NormalizedOptions, error: RequestError | undefined, retryCount: number | undefined): void;
    beforeRedirect(options: Parameters<BeforeRedirectHook>[0], clientResponse: Parameters<BeforeRedirectHook>[1]): void;
    beforeError(error: RequestError): void;
}
export declare function createHttpClientMetrics(prometheusMeter: PrometheusMeter): HttpClientMetrics;
interface HttpClientMetrics {
    requestDurations: Histogram<"host" | "status_code" | "is_retry" | "from_cache">;
    requestErrors: Counter<"host" | "error_name" | "code">;
}
export {};
