"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const root_logger_1 = require("./root_logger");
const logger_test_utils_1 = require("./logger_test_utils");
describe("RootLogger", () => {
    it("allows to create children", async () => {
        const destination = (0, logger_test_utils_1.createDestinationStream)();
        const logger = (0, root_logger_1.createRootLogger)("myService", { destination });
        const childLogger = logger.child({ childProp: "childProp" });
        const logPromise = (0, logger_test_utils_1.nextLog)(destination);
        childLogger.info("hello");
        const log = await logPromise;
        expect(log.childProp).toBe("childProp");
    });
    it("children log required fields", async () => {
        const destination = (0, logger_test_utils_1.createDestinationStream)();
        const rootLogger = (0, root_logger_1.createRootLogger)("myService", { destination });
        const logger = rootLogger.child({});
        const logPromise = (0, logger_test_utils_1.nextLog)(destination);
        logger.info("hello");
        const log = await logPromise;
        expect(typeof log["@timestamp"]).toBe("string");
        const timestampDiff = Date.now() - Date.parse(log["@timestamp"]);
        expect(timestampDiff).toBeGreaterThanOrEqual(0);
        expect(timestampDiff).toBeLessThan(10000);
        const timeDiff = Date.now() - log.time;
        expect(timeDiff).toBeGreaterThanOrEqual(0);
        expect(timeDiff).toBeLessThan(10000);
        expect(log.loglevel).toBe("INFO");
        expect(log.application_type).toBe("service");
        expect(log.service).toBe("myService");
        expect(typeof log.host).toBe("string");
    });
});
