"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.metricsPlugin = void 0;
const prom_client_1 = __importDefault(require("prom-client"));
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
const request_metrics_1 = require("./request_metrics");
const options_1 = require("../utils/options");
const prometheus_meter_1 = require("./prometheus_meter");
exports.metricsPlugin = (0, fastify_plugin_1.default)(
// eslint-disable-next-line @typescript-eslint/require-await
async (app, opts) => {
    // Use a dedicated local register instead of the global one
    const register = opts.register || new prom_client_1.default.Registry();
    void app.register(prometheus_meter_1.prometheusMeterPlugin, {
        // Use `register` by default, but may me overriden by specific options
        defaultRegisters: [register],
        ...opts.prometheusMeter,
    });
    if ((0, options_1.isOptionEnabled)(opts.defaultMetrics)) {
        // Use `register` by default, but may me overriden by specific options
        prom_client_1.default.collectDefaultMetrics({ register, ...opts.defaultMetrics });
    }
    if ((0, options_1.isOptionEnabled)(opts.requestMetrics)) {
        void app.register(request_metrics_1.requestMetricsPlugin, opts.requestMetrics);
    }
    app.route({
        method: "GET",
        url: opts.endpointPath || "/admin/metrics",
        config: { accessLogLevel: "DEBUG" },
        async handler(_request, reply) {
            void reply
                .type("text/plain; version=0.0.4")
                .send(await register.metrics());
        },
    });
}, {
    name: "metrics",
    fastify: "3.x",
});
