"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.duplicateStrategies = exports.createPrometheusMeter = void 0;
const R = __importStar(require("remeda"));
const promClient = __importStar(require("prom-client"));
function createPrometheusMeter(defaultRegisters, Counter = promClient.Counter, Gauge = promClient.Gauge, Histogram = promClient.Histogram, Summary = promClient.Summary) {
    return {
        defaultRegisters,
        createCounter(config) {
            return createMetric(Counter, defaultRegisters, config);
        },
        createGauge(config) {
            return createMetric(Gauge, defaultRegisters, config);
        },
        createHistogram(config) {
            return createMetric(Histogram, defaultRegisters, config);
        },
        createSummary(config) {
            return createMetric(Summary, defaultRegisters, config);
        },
    };
}
exports.createPrometheusMeter = createPrometheusMeter;
exports.duplicateStrategies = {
    preventAnyDuplicate,
    returnExistingIfPropsAreEqual,
};
function createMetric(MetricClass, defaultRegisters, config) {
    const finalConfig = {
        ...config,
        registers: config.registers || defaultRegisters,
    };
    if (typeof config.duplicateStrategy === "function") {
        const { registeredIn, notRegisteredIn } = devideRegisters(finalConfig.registers, finalConfig.name);
        return config.duplicateStrategy(MetricClass, finalConfig, registeredIn, notRegisteredIn);
    }
    else {
        // Do not perform any duplicate strategy and use promClient's default behaviour
        return new MetricClass(finalConfig);
    }
}
/**
 * Divides `registers` into:
 * - `registeredIn`: those that already contain a metric with the same name
 * - `notRegisteredIn`: all other
 */
function devideRegisters(registers, metricName) {
    const registeredIn = [];
    const notRegisteredIn = [];
    for (const registry of registers) {
        const metric = registry.getSingleMetric(metricName);
        if (metric !== undefined) {
            registeredIn.push({ registry, metric });
        }
        else {
            notRegisteredIn.push(registry);
        }
    }
    return { registeredIn, notRegisteredIn };
}
function preventAnyDuplicate(MetricClass, config, registeredIn, _notRegisteredIn) {
    if (registeredIn.length > 0) {
        throw new Error(`A metric with the name '${config.name}' has already been registered.`);
    }
    return new MetricClass(config);
}
function returnExistingIfPropsAreEqual(MetricClass, config, registeredIn, notRegisteredIn) {
    if (registeredIn.length < 1) {
        // Just create the metric
        return new MetricClass(config);
    }
    else {
        // => The metric is already registered in at least one registry
        // Check config property equality
        for (const { metric } of registeredIn) {
            if (!(metric instanceof MetricClass)) {
                throw new Error(`The re-registration of a metric with the name '${config.name}' is only allowed if they are of the same metric type.`);
            }
            const propsToCheck = ["name", "help", "labelNames"];
            const existingMetricProps = R.pick(metric, propsToCheck);
            const newMetricProps = R.pick(config, propsToCheck);
            newMetricProps["labelNames"] = newMetricProps["labelNames"] || [];
            if (!R.equals(existingMetricProps, newMetricProps)) {
                throw new Error(`The re-registration of a metric with the name '${config.name}' is only allowed if all of these properties equal: ${propsToCheck.join(", ")}`);
            }
        }
        // Check if they are registered in the same registries
        if (notRegisteredIn.length > 0) {
            throw new Error(`The re-registration of a metric with the name '${config.name}' is only allowed if their registries equal.`);
        }
        // Return existing metric from the first registry
        return registeredIn[0].metric;
    }
}
