"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestMetricsPlugin = void 0;
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
const utils_1 = require("../utils");
const defaultLabels = ["status_code", "method", "path"];
exports.requestMetricsPlugin = (0, fastify_plugin_1.default)(initRequestMetrics, {
    name: "request-metrics",
    fastify: "3.x",
    decorators: {
        fastify: ["prometheusMeter"],
    },
});
// eslint-disable-next-line @typescript-eslint/require-await
async function initRequestMetrics(app, opts) {
    const extraLabelNames = opts.extraLabelNames || [];
    const promMeter = opts.prometheusMeter ||
        (0, utils_1.throwIfUndefined)(app.prometheusMeter, "app.prometheusMeter");
    const durationHistogram = promMeter.createHistogram({
        name: "http_request_duration_seconds",
        help: "HTTP server response time in seconds",
        labelNames: [...defaultLabels, ...extraLabelNames],
    });
    app.decorate("requestMetrics", new RequestMetricsAppDecoration(durationHistogram));
    app.decorateRequest("requestMetrics", null);
    app.addHook("onRequest", function addRequestMetrics(request, _reply, done) {
        request.requestMetrics = new RequestMetricsRequestDecoration(extraLabelNames);
        done();
    });
    app.addHook("onResponse", function observeRequestDuration(request, reply, done) {
        durationHistogram.observe(
        // @ts-expect-error labels cause a type error that makes no sense to me
        {
            method: request.method || "unknown",
            path: reply.context.config.url || "unknown",
            status_code: reply.statusCode,
            ...(extraLabelNames ? request.requestMetrics.extraLabels : {}),
        }, reply.getResponseTime() / 1000);
        done();
    });
}
class RequestMetricsAppDecoration {
    constructor(durationHistogram) {
        this.durationHistogram = durationHistogram;
    }
}
class RequestMetricsRequestDecoration {
    constructor(labelNames) {
        this.labelNames = labelNames;
        this.extraLabels = {};
    }
    addLabel(name, value) {
        this.extraLabels[name] = value;
    }
}
