"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fastify_1 = __importDefault(require("fastify"));
const prom_client_1 = require("prom-client");
const request_metrics_1 = require("./request_metrics");
const prometheus_meter_1 = require("./prometheus_meter");
describe("Request metrics", () => {
    it("observes request durations", async () => {
        const app = (0, fastify_1.default)()
            .register(prometheus_meter_1.prometheusMeterPlugin, { defaultRegisters: [new prom_client_1.Registry()] })
            .register(request_metrics_1.requestMetricsPlugin)
            .get("/test/:someParam", (request, reply) => {
            void reply.send({ ok: "ok" });
        });
        await app.ready();
        const observeSpy = jest.spyOn(app.requestMetrics.durationHistogram, "observe");
        await app.inject({ url: "/test/abc123?d=4" });
        expect(observeSpy).toHaveBeenCalledTimes(1);
        expect(observeSpy.mock.calls[0][0]).toStrictEqual({
            method: "GET",
            path: "/test/:someParam",
            status_code: 200,
        });
        expect(observeSpy.mock.calls[0][1]).toBeGreaterThanOrEqual(0);
        await app.inject({ url: "/some/unkown/path" });
        expect(observeSpy).toHaveBeenCalledTimes(2);
        expect(observeSpy.mock.calls[1][0]).toStrictEqual({
            method: "GET",
            path: "unknown",
            status_code: 404,
        });
        expect(observeSpy.mock.calls[1][1]).toBeGreaterThanOrEqual(0);
        await app.close();
    });
    it("allows to add extra labels", async () => {
        const app = (0, fastify_1.default)()
            .register(prometheus_meter_1.prometheusMeterPlugin, { defaultRegisters: [new prom_client_1.Registry()] })
            .register(request_metrics_1.requestMetricsPlugin, {
            extraLabelNames: ["test_param", "optional_extra"],
        })
            .get("/test/:testParam", (request, reply) => {
            request.requestMetrics.addLabel("test_param", request.params.testParam);
            void reply.send({ ok: "ok" });
        });
        await app.ready();
        const observeSpy = jest.spyOn(app.requestMetrics.durationHistogram, "observe");
        await app.inject({ url: "/test/extra1" });
        expect(observeSpy).toHaveBeenCalledTimes(1);
        expect(observeSpy.mock.calls[0][0]).toStrictEqual({
            method: "GET",
            path: "/test/:testParam",
            status_code: 200,
            test_param: "extra1",
        });
        expect(observeSpy.mock.calls[0][1]).toBeGreaterThanOrEqual(0);
        await app.close();
    });
});
