"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.shutdownPlugin = void 0;
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
const utils_1 = require("../utils");
exports.shutdownPlugin = (0, fastify_plugin_1.default)(initShutdownPlugin, {
    name: "shutdown",
    fastify: "3.x",
});
// eslint-disable-next-line @typescript-eslint/require-await
async function initShutdownPlugin(app, opts) {
    const signals = opts.signals || ["SIGINT", "SIGTERM"];
    app.decorate("closeAndExitProcess", createCloseAndExitProcess(app));
    const shutdownOnSignal = createShutdownOnSignal(app);
    for (const signal of signals) {
        const isListenerAdded = (0, utils_1.addEventListenerOnlyOnce)(process, signal, shutdownOnSignal, true);
        if (isListenerAdded && process.listenerCount(signal) > 1) {
            app.log.warn(`Found an existing handler for ${signal}`);
        }
    }
}
function createCloseAndExitProcess(app) {
    return function closeAndExitProcess(processExitCode) {
        app.log.info("Closing resources and exit process with code %d", processExitCode);
        app.close(() => {
            app.log.info("Closing finished");
            process.exit(processExitCode);
        });
    };
}
function createShutdownOnSignal(app) {
    return function shutdownOnSignal(signal) {
        app.log.info("Received signal: %s", signal);
        app.closeAndExitProcess(0);
    };
}
