/// <reference types="node" />
import http from "http";
import { FastifyInstance, FastifyServerOptions } from "fastify";
import underPressure from "under-pressure";
import { LoggingOptions } from "./logging/logging.types";
import { RootLogger } from "./logging/root_logger";
import { HealthCheckOptions } from "./health_check";
import { MetricsOptions } from "./metrics";
import { HttpClientPluginOptions } from "./http_client";
import { CorrelationIdOptions } from "./correlation_id";
import { RequestLoggingOptions } from "./logging/request_logging_plugin";
import { ShutdownPluginOpts } from "./shutdown";
import { Enableable } from "./utils/options";
export declare function createServiceSkeleton(opts: ServiceSkeletonOptions): FastifyInstance<http.Server>;
export interface ServiceSkeletonOptions {
    serviceName: string;
    fastify?: Omit<FastifyServerOptions, "logger">;
    logging?: Enableable<LoggingOptions>;
    enablePluginsByDefault?: boolean;
    plugins?: {
        healthCheck?: Enableable<HealthCheckOptions>;
        correlationId?: Enableable<CorrelationIdOptions>;
        requestLogging?: Enableable<RequestLoggingOptions>;
        metrics?: Enableable<MetricsOptions>;
        httpClient?: Enableable<HttpClientPluginOptions>;
        sensible?: boolean;
        shutdown?: Enableable<ShutdownPluginOpts>;
        underPressure?: Enableable<underPressure.UnderPressureOptions>;
    };
}
declare module "fastify" {
    interface FastifyInstance {
        rootLogger: RootLogger;
    }
}
