"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cachedStringHasher = void 0;
const crypto_1 = require("crypto");
class CachedStringHasher {
    constructor() {
        this.memory = {};
    }
    hash(str, algorithm = "sha256", encoding = "base64") {
        if (Object.prototype.hasOwnProperty.call(this.memory, str)) {
            return this.memory[str];
        }
        const salt = (0, crypto_1.randomBytes)(4).toString("hex");
        const hashed = {
            hash: (0, crypto_1.createHash)(algorithm)
                .update(salt + str)
                .digest(encoding),
            prependedSalt: salt,
            algorithm,
            encoding,
        };
        this.memory[str] = hashed;
        return hashed;
    }
}
exports.cachedStringHasher = new CachedStringHasher();
