"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationError = exports.Validator = void 0;
const ajv_1 = __importDefault(require("ajv"));
const ajv_formats_1 = __importDefault(require("ajv-formats"));
const staticAjvInstance = (0, ajv_formats_1.default)(new ajv_1.default());
class Validator {
    constructor(schemaName, schema, options) {
        const ajv = options ? (0, ajv_formats_1.default)(new ajv_1.default(options)) : staticAjvInstance;
        this.validateFunc = ajv.compile(schema);
        this.schema = schema;
        this.schemaName = schemaName;
    }
    validate(candidate, resultHandler) {
        const isValid = this.validateFunc(candidate);
        if (resultHandler) {
            const errors = this.validateFunc.errors ?? null;
            resultHandler(errors !== null
                ? new ValidationError(candidate, this.schemaName, this.schema, errors)
                : null, {
                candidate,
                schema: this.schema,
                schemaName: this.schemaName,
            });
        }
        return isValid;
    }
    // static because `asserts` return type did not work with TypeScript 3.7.4
    static assert(validator, candidate, resultHandler) {
        if (!validator.validate(candidate, resultHandler)) {
            throw new ValidationError(candidate, validator.schemaName, validator.schema, validator.validateFunc.errors);
        }
    }
}
exports.Validator = Validator;
class ValidationError extends Error {
    constructor(candidate, schemaName, schema, validationErrors) {
        super(`Invalid ${schemaName}: ${staticAjvInstance.errorsText(validationErrors)}`);
        this.candidate = candidate;
        this.schemaName = schemaName;
        this.schema = schema;
        this.validationErrors = validationErrors;
    }
}
exports.ValidationError = ValidationError;
